@@ -29,7 +29,7 @@ CPAN::Testers::ParseReport - parse reports to www.cpantesters.org from various s
 
 =cut
 
-use version; our $VERSION = qv('0.1.10');
+use version; our $VERSION = qv('0.1.11');
 
 =head1 SYNOPSIS
 
@@ -606,7 +606,7 @@ sub parse_report {
                     $extract{"meta:writer"} = "CPANPLUS $1";
                 } elsif (/created (?:automatically )?by (\S+)/) {
                     $extract{"meta:writer"} = $1;
-                    if (/\s+on\s+perl\s+(\S+),/) {
+                    if (/\s+on\s+perl\s+([^,]+),/) {
                         $fallback_p5 = $1;
                     }
                 } elsif (/This report was machine-generated by (\S+) (\S+)/) {
@@ -695,6 +695,10 @@ sub parse_report {
                 } elsif ($moduleunpack->{type} == 2) {
                     (my $leader,$module,$v,$needwant) = eval { unpack $moduleunpack->{tpl}, $_; };
                     next LINE if $@;
+                    for ($module,$v,$needwant) {
+                        s/^\s+//;
+                        s/\s+$//;
+                    }
                     if ($leader =~ /^\*/) {
                         $moduleunpack = {};
                         $expect_prereq = 0;
@@ -777,7 +781,9 @@ sub parse_report {
         }
     }                           # LINE
     if (! $extract{"meta:perl"} && $fallback_p5) {
-        $extract{"meta:perl"} = $fallback_p5;
+        my($p5,$patch) = split /\s+patch\s+/, $fallback_p5;
+        $extract{"meta:perl"} = $p5;
+        $extract{"conf:git_describe"} = $patch if defined $patch;
     }
     if ($Opt{solve}) {
         $extract{id} = $id;
